# Copyright 2024 Cisco Systems, Inc. and its affiliates
from __future__ import annotations

from typing import Any, Optional

from catalystwan.abc import RequestAdapterInterface

from . import models
from .models import GenerateRediscoverInfo


class RediscoverBuilder:
    """
    Builds and executes requests for operations under /device/action/rediscover
    """

    m = models

    def __init__(self, request_adapter: RequestAdapterInterface) -> None:
        self._request_adapter = request_adapter

    def generate_rediscover_info(self, **kw) -> GenerateRediscoverInfo:
        """
        Get rediscover operation information

        :returns: GenerateRediscoverInfo
        """
        return self._request_adapter.request(
            "GET", "/dataservice/device/action/rediscover", return_type=GenerateRediscoverInfo, **kw
        )

    def re_discover_devices(self, payload: Optional[Any] = None, **kw):
        """
        Rediscover device

        :param payload: Rediscover device request payload
        :returns: None
        """
        return self._request_adapter.request(
            "POST", "/dataservice/device/action/rediscover", payload=payload, **kw
        )
